import{_ as m}from"./TasksView.vue_vue_type_script_setup_true_lang.508a3d79.js";import{R as f}from"./tasksController.11e798f4.js";import{d as b,ea as _,f as y,o as n,Y as g,b as w,w as k,u as l,c as I,S as T,aS as v,aG as B,dd as S}from"./index.00900164.js";import"./gateway.61e97762.js";import{a as j,B as x}from"./build.61f8db9a.js";import{a as C}from"./project.60119477.js";import"./tables.3355581b.js";import{a as D}from"./asyncComputed.61a4e861.js";import"./metadata.04a8e452.js";import"./PhRobot.vue.bf1c44bc.js";import"./PhWebhooksLogo.vue.389dc446.js";import"./ant-design.a6952f3b.js";import"./string.a628f102.js";import"./dayjs.bffb7cbc.js";import"./index.904b961c.js";import"./linters.4ffd16b2.js";import"./scripts.d54186dc.js";import"./record.9a19fe6f.js";import"./polling.4c55b326.js";import"./popupNotifcation.105ba4a6.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="0ef30d2f-5e42-4172-8481-a0b62a1fbb00",e._sentryDebugIdIdentifier="sentry-dbid-0ef30d2f-5e42-4172-8481-a0b62a1fbb00")}catch{}})();const U=b({__name:"Tasks",setup(e){const a=_().params.projectId,p=new f(a),{result:o}=D(async()=>{const r=(await j.list(a)).find(c=>c.latest);if(!r)return null;const[u,d]=await Promise.all([x.get(r.id),C.get(a)]);return{buildSpec:u,project:d}}),i=y(()=>!o.value||!o.value.buildSpec?null:o.value.buildSpec.runtimes.map(t=>({id:t.id,stageTitle:t.title,stageType:t.type})));return(t,r)=>(n(),g(v,null,[w(l(S),null,{default:k(()=>[B("Tasks")]),_:1}),i.value?(n(),I(m,{key:0,class:"tasks",api:l(p),stages:i.value},null,8,["api","stages"])):T("",!0)],64))}});export{U as default};
//# sourceMappingURL=Tasks.9ac265d7.js.map
