import{_ as n,C as p}from"./View.vue_vue_type_script_setup_true_lang.d1715804.js";import{d as i,ea as a,o as s,c as m,u as c}from"./index.00900164.js";import"./gateway.61e97762.js";import"./popupNotifcation.105ba4a6.js";import"./fetch.37bc41e4.js";import"./record.9a19fe6f.js";import"./SaveButton.66a17872.js";import"./UnsavedChangesHandler.ad175023.js";import"./ExclamationCircleOutlined.fde09017.js";import"./CrudView.0cb65aba.js";import"./router.2cec9d72.js";import"./Badge.424cfeb2.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.59fb8def.js";import"./BookOutlined.d78d7289.js";import"./url.81ce8e9e.js";import"./PhDotsThreeVertical.vue.f7911e43.js";import"./index.904b961c.js";import"./index.cdbf7d0b.js";import"./asyncComputed.61a4e861.js";import"./polling.4c55b326.js";import"./PhPencil.vue.d124c936.js";import"./index.c337cd49.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="a800269a-4185-48e8-8e6a-909b86a11ac6",o._sentryDebugIdIdentifier="sentry-dbid-a800269a-4185-48e8-8e6a-909b86a11ac6")}catch{}})();const A=i({__name:"EnvVars",setup(o){const e=a().params.projectId,t=new p(e);return(d,u)=>(s(),m(n,{"env-var-repository":c(t),mode:"console"},null,8,["env-var-repository"]))}});export{A as default};
//# sourceMappingURL=EnvVars.c00be9e7.js.map
