import{d as o,o as a,Y as s,b as d,u as r,by as _,a0 as c}from"./index.00900164.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="88f2c270-01c3-45fa-95e5-8d5573eee31f",e._sentryDebugIdIdentifier="sentry-dbid-88f2c270-01c3-45fa-95e5-8d5573eee31f")}catch{}})();const i={class:"centered"},f=o({__name:"LoadingContainer",setup(e){return(n,t)=>(a(),s("div",i,[d(r(_))]))}});const u=c(f,[["__scopeId","data-v-52e6209a"]]);export{u as L};
//# sourceMappingURL=LoadingContainer.daeb0d26.js.map
