import{P as f}from"./PlayerNavbar.e38a5401.js";import{d as g,eo as h,ea as i,e as b,f as y,r as k,o as c,Y as v,u as n,c as w,S as L,a as C,b as I,a0 as N}from"./index.00900164.js";import{u as V}from"./workspaceStore.5ccc82e1.js";import"./metadata.04a8e452.js";import"./PhRobot.vue.bf1c44bc.js";import"./PhWebhooksLogo.vue.389dc446.js";import"./LoadingOutlined.30286f42.js";import"./PhSignOut.vue.29943a16.js";import"./index.7e967143.js";import"./Avatar.8b92ae0e.js";import"./url.81ce8e9e.js";import"./colorHelpers.2d30f02e.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="1d2a160f-2bfb-495d-bc6a-76a630e98633",o._sentryDebugIdIdentifier="sentry-dbid-1d2a160f-2bfb-495d-bc6a-76a630e98633")}catch{}})();const x={class:"main-container"},B={class:"content"},D=g({__name:"Main",setup(o){const e=h(),t=V(),d=i().path,a=b(null),u=async({path:r,id:s})=>{a.value=s,await e.push({path:`/${r}`}),a.value=null},l=()=>{e.push({name:"playerLogin"})},p=()=>{e.push({name:"playerLogin"})},_=y(()=>!!i().meta.hideLogin);return(r,s)=>{const m=k("RouterView");return c(),v("div",x,[n(t).state.workspace?(c(),w(f,{key:0,"current-path":n(d),"hide-login":_.value,"runner-data":n(t).state.workspace,loading:a.value,onNavigate:u,onLoginClick:p,onLogoutClick:l},null,8,["current-path","hide-login","runner-data","loading"])):L("",!0),C("section",B,[I(m)])])}}});const F=N(D,[["__scopeId","data-v-f095bece"]]);export{F as default};
//# sourceMappingURL=Main.aa26e5e6.js.map
