import{k as a,T as n,m as r,P as o,C as p,M as d,s as f,n as s,p as c,q as m,t as u,v as g}from"./index.00900164.js";import{s as b,c as y,a as i}from"./workspaceStore.5ccc82e1.js";import{_ as l}from"./App.vue_vue_type_style_index_0_lang.d87886e2.js";import"./url.81ce8e9e.js";import"./colorHelpers.2d30f02e.js";import"./PlayerConfigProvider.4f10c0d1.js";import"./index.7b4c552b.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="ff3270b2-9f86-4e02-8439-fca60a830eb4",t._sentryDebugIdIdentifier="sentry-dbid-ff3270b2-9f86-4e02-8439-fca60a830eb4")}catch{}})();class w{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await b();const t=y(),e=a({render:()=>c(l)});n.init(),r(e,i),w.init(),e.use(i),e.use(t),e.use(o),e.mount("#app"),e.component("VSelect",p),e.component("Markdown",d),e.component("Message",f),s(e,m),s(e,u),s(e,g)})();
//# sourceMappingURL=player.2618ddc5.js.map
