import"./App.vue_vue_type_style_index_0_lang.d87886e2.js";import{_ as c}from"./App.vue_vue_type_style_index_0_lang.d87886e2.js";import"./workspaceStore.5ccc82e1.js";import"./index.00900164.js";import"./url.81ce8e9e.js";import"./colorHelpers.2d30f02e.js";import"./PlayerConfigProvider.4f10c0d1.js";import"./index.7b4c552b.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="d2183cf3-66a0-4831-a792-b628cf852ea6",e._sentryDebugIdIdentifier="sentry-dbid-d2183cf3-66a0-4831-a792-b628cf852ea6")}catch{}})();export{c as default};
//# sourceMappingURL=App.a523a2a8.js.map
