import{cM as o}from"./index.00900164.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="00aea97d-9f4c-4af6-9215-2a5b36859235",e._sentryDebugIdIdentifier="sentry-dbid-00aea97d-9f4c-4af6-9215-2a5b36859235")}catch{}})();const d=(e,r,n)=>{o.error({message:e,description:r,onClick:n})};export{d as p};
//# sourceMappingURL=popupNotifcation.105ba4a6.js.map
