import{O as r}from"./workspaceStore.5ccc82e1.js";import{d as c,X as l,o as i,Y as u,b as a,w as o,u as n,aG as d,dd as f,dc as b}from"./index.00900164.js";import"./url.81ce8e9e.js";import"./colorHelpers.2d30f02e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="c699ff09-cd85-405a-bfce-c85359eabaad",e._sentryDebugIdIdentifier="sentry-dbid-c699ff09-cd85-405a-bfce-c85359eabaad")}catch{}})();const w=c({__name:"OidcLogoutCallback",setup(e){return l(async()=>{await new r().logoutCallback()}),(t,s)=>(i(),u("div",null,[a(n(f),null,{default:o(()=>[d("You're authenticated")]),_:1}),a(n(b),null,{default:o(()=>[d(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{w as default};
//# sourceMappingURL=OidcLogoutCallback.3f416bf1.js.map
