import{_ as d}from"./TasksView.vue_vue_type_script_setup_true_lang.508a3d79.js";import{L as p}from"./tasksController.11e798f4.js";import{d as f,e as u,o as _,c as m,w as t,b as s,u as o,dd as y,aG as i,bT as b,dh as k,a0 as w}from"./index.00900164.js";import{C as T}from"./ContentLayout.46cee630.js";import{a as g}from"./ant-design.a6952f3b.js";import"./metadata.04a8e452.js";import"./PhRobot.vue.bf1c44bc.js";import"./PhWebhooksLogo.vue.389dc446.js";import"./string.a628f102.js";import"./dayjs.bffb7cbc.js";import"./index.904b961c.js";import"./gateway.61e97762.js";import"./popupNotifcation.105ba4a6.js";import"./linters.4ffd16b2.js";import"./asyncComputed.61a4e861.js";import"./scripts.d54186dc.js";import"./record.9a19fe6f.js";import"./polling.4c55b326.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="9a97a384-55ee-40cf-892c-cd88b70d80b3",e._sentryDebugIdIdentifier="sentry-dbid-9a97a384-55ee-40cf-892c-cd88b70d80b3")}catch{}})();const x=f({__name:"Tasks",setup(e){const a=new p,r=u(null);async function l(){var n;await g("Are you sure you want to clear all tasks and their associated payloads?")&&await((n=r.value)==null?void 0:n.clearAllTasks())}return(c,n)=>(_(),m(T,null,{default:t(()=>[s(o(k),{justify:"space-between",align:"center"},{default:t(()=>[s(o(y),null,{default:t(()=>[i("Tasks")]),_:1}),s(o(b),{type:"link",style:{"margin-top":"10px"},onClick:l},{default:t(()=>[i("Clear all")]),_:1})]),_:1}),s(d,{ref_key:"tasksTableView",ref:r,class:"tasks",api:o(a),stages:null,editor:""},null,8,["api"])]),_:1}))}});const H=w(x,[["__scopeId","data-v-4b92e2a9"]]);export{H as default};
//# sourceMappingURL=Tasks.87ce9367.js.map
