import{U as s,dA as d,dB as i}from"./index.00900164.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="7da6cb24-41cb-4af3-9cb2-1d9f2ec79a9c",e._sentryDebugIdIdentifier="sentry-dbid-7da6cb24-41cb-4af3-9cb2-1d9f2ec79a9c")}catch{}})();const{DatePicker:n,WeekPicker:t,MonthPicker:c,YearPicker:f,TimePicker:b,QuarterPicker:r,RangePicker:a}=d(i),u=s(n,{WeekPicker:t,MonthPicker:c,YearPicker:f,RangePicker:a,TimePicker:b,QuarterPicker:r,install:e=>(e.component(n.name,n),e.component(a.name,a),e.component(c.name,c),e.component(t.name,t),e.component(r.name,r),e)});export{u as D,c as M,r as Q,a as R,t as W};
//# sourceMappingURL=dayjs.bffb7cbc.js.map
