import{d as i,o as p,c as n,w as a,b as m,u as e}from"./index.00900164.js";import"./linters.4ffd16b2.js";import{W as s}from"./workspaces.882dbbfd.js";import{C as d}from"./ContentLayout.46cee630.js";import{_ as f,E as c}from"./View.vue_vue_type_script_setup_true_lang.d1715804.js";import"./asyncComputed.61a4e861.js";import"./workspaceStore.5ccc82e1.js";import"./url.81ce8e9e.js";import"./colorHelpers.2d30f02e.js";import"./record.9a19fe6f.js";import"./gateway.61e97762.js";import"./popupNotifcation.105ba4a6.js";import"./fetch.37bc41e4.js";import"./SaveButton.66a17872.js";import"./UnsavedChangesHandler.ad175023.js";import"./ExclamationCircleOutlined.fde09017.js";import"./CrudView.0cb65aba.js";import"./router.2cec9d72.js";import"./Badge.424cfeb2.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.59fb8def.js";import"./BookOutlined.d78d7289.js";import"./PhDotsThreeVertical.vue.f7911e43.js";import"./index.904b961c.js";import"./index.cdbf7d0b.js";import"./polling.4c55b326.js";import"./PhPencil.vue.d124c936.js";import"./index.c337cd49.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="a0ab17ea-c8c7-4194-9fec-66e9403b578b",o._sentryDebugIdIdentifier="sentry-dbid-a0ab17ea-c8c7-4194-9fec-66e9403b578b")}catch{}})();const G=i({__name:"EnvVarsEditor",setup(o){const r=new c;return(t,u)=>(p(),n(d,null,{default:a(()=>[m(f,{"env-var-repository":e(r),mode:"editor","file-opener":e(s)},null,8,["env-var-repository","file-opener"])]),_:1}))}});export{G as default};
//# sourceMappingURL=EnvVarsEditor.10dc4a0d.js.map
