import"./index.00900164.js";(function(){try{var x=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(x._sentryDebugIds=x._sentryDebugIds||{},x._sentryDebugIds[d]="4cf8b0c9-f2dd-42f5-aa1d-c99d0dc2c456",x._sentryDebugIdIdentifier="sentry-dbid-4cf8b0c9-f2dd-42f5-aa1d-c99d0dc2c456")}catch{}})();const t=()=>"xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(/[xy]/g,function(x){const d=Math.random()*16|0;return(x=="x"?d:d&3|8).toString(16)});export{t as u};
//# sourceMappingURL=uuid.93ac9996.js.map
