import{d as n,o as a,Y as s,a as d,$ as r,ed as l,a0 as _}from"./index.00900164.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="083b8436-18a0-4335-9a17-7ba13d893f37",e._sentryDebugIdIdentifier="sentry-dbid-083b8436-18a0-4335-9a17-7ba13d893f37")}catch{}})();const u={class:"content-layout"},c=n({__name:"ContentLayout",props:{fullWidth:{type:Boolean}},setup(e){return(t,o)=>(a(),s("div",u,[d("div",{class:l(["centered-layout",{"full-width":t.fullWidth}])},[r(t.$slots,"default",{},void 0,!0)],2)]))}});const f=_(c,[["__scopeId","data-v-6397d501"]]);export{f as C};
//# sourceMappingURL=ContentLayout.46cee630.js.map
